aboutsummaryrefslogtreecommitdiffstats
path: root/libsolidity/CompilerUtils.h
diff options
context:
space:
mode:
Diffstat (limited to 'libsolidity/CompilerUtils.h')
-rw-r--r--libsolidity/CompilerUtils.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/libsolidity/CompilerUtils.h b/libsolidity/CompilerUtils.h
index f335eed5..01b9f422 100644
--- a/libsolidity/CompilerUtils.h
+++ b/libsolidity/CompilerUtils.h
@@ -124,10 +124,11 @@ public:
/// Copies an item that occupies @a _itemSize stack slots from a stack depth of @a _stackDepth
/// to the top of the stack.
void copyToStackTop(unsigned _stackDepth, unsigned _itemSize);
- /// Moves a single stack element (with _stackDepth items on top of it) to the top of the stack.
- void moveToStackTop(unsigned _stackDepth);
- /// Moves a single stack element past @a _stackDepth other stack elements
- void moveIntoStack(unsigned _stackDepth);
+ /// Moves an item that occupies @a _itemSize stack slots and has items occupying @a _stackDepth
+ /// slots above it to the top of the stack.
+ void moveToStackTop(unsigned _stackDepth, unsigned _itemSize = 1);
+ /// Moves @a _itemSize elements past @a _stackDepth other stack elements
+ void moveIntoStack(unsigned _stackDepth, unsigned _itemSize = 1);
/// Removes the current value from the top of the stack.
void popStackElement(Type const& _type);
/// Removes element from the top of the stack _amount times.